#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_FACT_11_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_FACT_11_HPP_INCLUDED

#include <boost/simd/constant/include/constants/fact_11.hpp>

#endif
